/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


namespace ElmSharp.Accessible
{
    /// <summary>
    /// Enumeration for AccessRole.
    /// </summary>
    public enum AccessRole
    {
        /// <summary>
        /// Invalid
        /// </summary>
        Invalid,
        /// <summary>
        /// AcceleratorLabel role
        /// </summary>
        AcceleratorLabel,
        /// <summary>
        /// Alert role
        /// </summary>
        Alert,
        /// <summary>
        /// Animation role
        /// </summary>
        Animation,
        /// <summary>
        /// Arrow role
        /// </summary>
        Arrow,
        /// <summary>
        /// Calendar role
        /// </summary>
        Calendar,
        /// <summary>
        /// Canvas role
        /// </summary>
        Canvas,
        /// <summary>
        /// CheckBox role
        /// </summary>
        CheckBox,
        /// <summary>
        /// CheckMenuItem role
        /// </summary>
        CheckMenuItem,
        /// <summary>
        /// ColorChooser role
        /// </summary>
        ColorChooser,
        /// <summary>
        /// ColumnHeader role
        /// </summary>
        ColumnHeader,
        /// <summary>
        /// ComboBox role
        /// </summary>
        ComboBox,
        /// <summary>
        /// DateEditor role
        /// </summary>
        DateEditor,
        /// <summary>
        /// DesktopIcon role
        /// </summary>
        DesktopIcon,
        /// <summary>
        /// DesktopFrame role
        /// </summary>
        DesktopFrame,
        /// <summary>
        /// Dial role
        /// </summary>
        Dial,
        /// <summary>
        /// Dialog role
        /// </summary>
        Dialog,
        /// <summary>
        /// DirectoryPane role
        /// </summary>
        DirectoryPane,
        /// <summary>
        /// DrawingArea role
        /// </summary>
        DrawingArea,
        /// <summary>
        /// FileChooser role
        /// </summary>
        FileChooser,
        /// <summary>
        /// Filler role
        /// </summary>
        Filler,
        /// <summary>
        /// FocusTraversable role
        /// </summary>
        FocusTraversable,
        /// <summary>
        /// FontChooser role
        /// </summary>
        FontChooser,
        /// <summary>
        /// Frame role
        /// </summary>
        Frame,
        /// <summary>
        /// GlassPane role
        /// </summary>
        GlassPane,
        /// <summary>
        /// HtmlContainer role
        /// </summary>
        HtmlContainer,
        /// <summary>
        /// Icon role
        /// </summary>
        Icon,
        /// <summary>
        /// Image role
        /// </summary>
        Image,
        /// <summary>
        /// InternalFrame role
        /// </summary>
        InternalFrame,
        /// <summary>
        /// Label role
        /// </summary>
        Label,
        /// <summary>
        /// LayeredPane role
        /// </summary>
        LayeredPane,
        /// <summary>
        /// List role
        /// </summary>
        List,
        /// <summary>
        /// ListItem role
        /// </summary>
        ListItem,
        /// <summary>
        /// Menu role
        /// </summary>
        Menu,
        /// <summary>
        /// MenuBar role
        /// </summary>
        MenuBar,
        /// <summary>
        /// MenuItem role
        /// </summary>
        MenuItem,
        /// <summary>
        /// OptionPane role
        /// </summary>
        OptionPane,
        /// <summary>
        /// PageTab role
        /// </summary>
        PageTab,
        /// <summary>
        /// PageTabList role
        /// </summary>
        PageTabList,
        /// <summary>
        /// Panel role
        /// </summary>
        Panel,
        /// <summary>
        /// PasswordText role
        /// </summary>
        PasswordText,
        /// <summary>
        /// PopupMenu role
        /// </summary>
        PopupMenu,
        /// <summary>
        /// ProgressBar role
        /// </summary>
        ProgressBar,
        /// <summary>
        /// PushButton role
        /// </summary>
        PushButton,
        /// <summary>
        /// RadioButton role
        /// </summary>
        RadioButton,
        /// <summary>
        /// RadioMenuItem role
        /// </summary>
        RadioMenuItem,
        /// <summary>
        /// RootPane role
        /// </summary>
        RootPane,
        /// <summary>
        /// RowHeader role
        /// </summary>
        RowHeader,
        /// <summary>
        /// ScrollBar role
        /// </summary>
        ScrollBar,
        /// <summary>
        /// ScrollPane role
        /// </summary>
        ScrollPane,
        /// <summary>
        /// Separator role
        /// </summary>
        Separator,
        /// <summary>
        /// Slider role
        /// </summary>
        Slider,
        /// <summary>
        /// SpinButton role
        /// </summary>
        SpinButton,
        /// <summary>
        /// SplitPane role
        /// </summary>
        SplitPane,
        /// <summary>
        /// StatusBar role
        /// </summary>
        StatusBar,
        /// <summary>
        /// Table role
        /// </summary>
        Table,
        /// <summary>
        /// TableCell role
        /// </summary>
        TableCell,
        /// <summary>
        /// TableColumnHeader role
        /// </summary>
        TableColumnHeader,
        /// <summary>
        /// TableRowHeader role
        /// </summary>
        TableRowHeader,
        /// <summary>
        /// TearoffMenuItem role
        /// </summary>
        TearoffMenuItem,
        /// <summary>
        /// Terminal role
        /// </summary>
        Terminal,
        /// <summary>
        /// Text role
        /// </summary>
        Text,
        /// <summary>
        /// ToggleButton role
        /// </summary>
        ToggleButton,
        /// <summary>
        /// ToolBar role
        /// </summary>
        ToolBar,
        /// <summary>
        /// ToolTip role
        /// </summary>
        ToolTip,
        /// <summary>
        /// Tree role
        /// </summary>
        Tree,
        /// <summary>
        /// TreeTable role
        /// </summary>
        TreeTable,
        /// <summary>
        /// Unknown
        /// </summary>
        Unknown,
        /// <summary>
        /// Viewport role
        /// </summary>
        Viewport,
        /// <summary>
        /// Window role
        /// </summary>
        Window,
        /// <summary>
        /// Extended role
        /// </summary>
        Extended,
        /// <summary>
        /// Header role
        /// </summary>
        Header,
        /// <summary>
        /// Footer role
        /// </summary>
        Footer,
        /// <summary>
        /// Paragraph
        /// </summary>
        Paragraph,
        /// <summary>
        /// Ruler role
        /// </summary>
        Ruler,
        /// <summary>
        /// Application role
        /// </summary>
        Application,
        /// <summary>
        /// Autocomplete role
        /// </summary>
        Autocomplete,
        /// <summary>
        /// Editbar role
        /// </summary>
        Editbar,
        /// <summary>
        /// Embedded role
        /// </summary>
        Embedded,
        /// <summary>
        /// Entry role
        /// </summary>
        Entry,
        /// <summary>
        /// Chart role
        /// </summary>
        Chart,
        /// <summary>
        /// Caption role
        /// </summary>
        Caption,
        /// <summary>
        /// DocumentFrame role
        /// </summary>
        DocumentFrame,
        /// <summary>
        /// Heading role
        /// </summary>
        Heading,
        /// <summary>
        /// Page role
        /// </summary>
        Page,
        /// <summary>
        /// Section role
        /// </summary>
        Section,
        /// <summary>
        /// RedundantObject role
        /// </summary>
        RedundantObject,
        /// <summary>
        /// Form role
        /// </summary>
        Form,
        /// <summary>
        /// Link role
        /// </summary>
        Link,
        /// <summary>
        /// InputMethodWindow role
        /// </summary>
        InputMethodWindow,
        /// <summary>
        /// TableRow role
        /// </summary>
        TableRow,
        /// <summary>
        /// TreeItem role
        /// </summary>
        TreeItem,
        /// <summary>
        /// DocumentSpreadsheet role
        /// </summary>
        DocumentSpreadsheet,
        /// <summary>
        /// DocumentPresentation role
        /// </summary>
        DocumentPresentation,
        /// <summary>
        /// DocumentText role
        /// </summary>
        DocumentText,
        /// <summary>
        /// DocumentWeb role
        /// </summary>
        DocumentWeb,
        /// <summary>
        /// DocumentEmail role
        /// </summary>
        DocumentEmail,
        /// <summary>
        /// Comment role
        /// </summary>
        Comment,
        /// <summary>
        /// ListBox role
        /// </summary>
        ListBox,
        /// <summary>
        /// Grouping role
        /// </summary>
        Grouping,
        /// <summary>
        /// ImageMap role
        /// </summary>
        ImageMap,
        /// <summary>
        /// Notification role
        /// </summary>
        Notification,
        /// <summary>
        /// InfoBar role
        /// </summary>
        InfoBar
    }
}
